-- ex2.init.sql

DROP TABLE IF EXISTS miniblog, mb_comment, mb_user, mb_tag;

CREATE TABLE mb_user (
  uid     serial primary key,
  uname   text unique,
  uinf    varchar(200)
);

CREATE TABLE miniblog (
  bid     bigserial primary key,
  message varchar(140),
  ts      timestamp DEFAULT current_timestamp,
  uid     int REFERENCES mb_user (uid)
);

CREATE TABLE mb_comment (
  cid     bigserial primary key,
  bid     bigint REFERENCES miniblog (bid),
  message varchar(140),
  ts      timestamp DEFAULT current_timestamp,
  uid     int REFERENCES mb_user (uid)
);

CREATE TABLE mb_tag (
  bid	bigint primary key REFERENCES miniblog (bid),
  tags  text[]
) WITH (fillfactor=70) ;

\set n_user 100
\set n_entry 20

BEGIN;

INSERT INTO mb_user (uname, uinf) 
  SELECT substr(md5(g::text), 8, 8), repeat(md5(g::text), 2)
  FROM generate_series(1, :n_user ) AS g;

INSERT INTO miniblog (message, uid, ts)
  SELECT repeat(md5(g::text), ceil(random() * 4)::int), 1 + g % :n_user,
    statement_timestamp()
  FROM generate_series(1, :n_user * :n_entry ) AS g;

INSERT INTO mb_comment (bid, message, uid, ts)
  SELECT ceil(random() * :n_user * :n_entry ),
    repeat(md5(g::text), ceil(random() * 3)::int),
    ceil(random() * :n_user ), statement_timestamp()
  FROM generate_series(1, :n_user * :n_entry * 2) as g;

INSERT INTO mb_tag (bid, tags)
  SELECT g, ARRAY[ substr(md5((g % 100)::text), 1, 3) , '', '', '', '']
    FROM generate_series(1, :n_user * :n_entry) AS g;

DO LANGUAGE plpgsql $$
BEGIN
 FOR i IN 0..99 LOOP
  UPDATE mb_tag
   SET tags[ ceil(random() * 5)::int ] = substr(md5(i::text), 1, 3)
   WHERE (bid % 1000)::bigint = floor(random() * 1000)::bigint;
 END LOOP;
END;
$$;

END;
