-- ex3.init.sql

DROP TABLE IF EXISTS miniblog, mb_comment, mb_user, mb_tag;

CREATE TABLE mb_comment (
    cid bigserial NOT NULL,
    bid bigint,
    message character varying(140),
    ts timestamp without time zone DEFAULT now(),
    uid integer
)
WITH (fillfactor='100');

CREATE TABLE mb_tag (
    bid bigint NOT NULL,
    tags text[]
)
WITH (fillfactor='100');

CREATE TABLE mb_user (
    uid serial NOT NULL,
    uname text,
    uinf character varying(200)
)
WITH (fillfactor='100');

CREATE TABLE miniblog (
    bid bigserial NOT NULL,
    message character varying(140),
    ts timestamp without time zone DEFAULT now(),
    uid integer
)
WITH (fillfactor='100');


\set n_user 10000
\set n_entry 50

BEGIN;

INSERT INTO mb_user (uname, uinf) 
  SELECT substr(md5(g::text), 8, 8), repeat(md5(g::text), 2)
  FROM generate_series(1, :n_user ) AS g;

INSERT INTO miniblog (message, uid, ts)
  SELECT repeat(md5(g::text), ceil(random() * 4)::int), 1 + g % :n_user,
    statement_timestamp()
  FROM generate_series(1, :n_user * :n_entry ) AS g;

INSERT INTO mb_comment (bid, message, uid, ts)
  SELECT ceil(random() * :n_user * :n_entry ),
    repeat(md5(g::text), ceil(random() * 3)::int),
    ceil(random() * :n_user ), statement_timestamp()
  FROM generate_series(1, :n_user * :n_entry * 2) as g;

INSERT INTO mb_tag (bid, tags)
  SELECT g, ARRAY[ substr(md5((g % 100)::text), 1, 3) , '', '', '', '']
    FROM generate_series(1, :n_user * :n_entry) AS g;

DO LANGUAGE plpgsql $$
BEGIN
 FOR i IN 0..99 LOOP
  UPDATE mb_tag
   SET tags[ ceil(random() * 5)::int ] = substr(md5(i::text), 1, 3)
   WHERE (bid % 1000)::bigint = floor(random() * 1000)::bigint;
 END LOOP;
END;
$$;

END;

ALTER TABLE ONLY mb_comment
  ADD CONSTRAINT mb_comment_pkey PRIMARY KEY (cid);
ALTER TABLE ONLY mb_tag
  ADD CONSTRAINT mb_tag_pkey PRIMARY KEY (bid);
ALTER TABLE ONLY mb_user
  ADD CONSTRAINT mb_user_pkey PRIMARY KEY (uid);
ALTER TABLE ONLY mb_user
  ADD CONSTRAINT mb_user_uname_key UNIQUE (uname);
ALTER TABLE ONLY miniblog
  ADD CONSTRAINT miniblog_pkey PRIMARY KEY (bid);
ALTER TABLE ONLY mb_comment
  ADD CONSTRAINT mb_comment_bid_fkey 
    FOREIGN KEY (bid) REFERENCES miniblog(bid);
ALTER TABLE ONLY mb_comment
  ADD CONSTRAINT mb_comment_uid_fkey 
    FOREIGN KEY (uid) REFERENCES mb_user(uid);
ALTER TABLE ONLY mb_tag
  ADD CONSTRAINT mb_tag_bid_fkey 
    FOREIGN KEY (bid) REFERENCES miniblog(bid);
ALTER TABLE ONLY miniblog
  ADD CONSTRAINT miniblog_uid_fkey 
    FOREIGN KEY (uid) REFERENCES mb_user(uid);
