#!/bin/bash
# create a data base cluster for ex3

EXDATA_PATH=~postgres
SCRIPT_PATH=$(cd $(dirname $0);pwd)

TESTDATA_USER_NUM=10000
TESTDATA_ENTRY_NUM=200

if [ $# -eq 1 ]; then
  TESTDATA_USER_NUM=$1
elif [ $# -eq 2 ]; then
  TESTDATA_USER_NUM=$1
  TESTDATA_ENTRY_NUM=$2
fi
expr $TESTDATA_USER_NUM + $TESTDATA_ENTRY_NUM > /dev/null 2>&1
if [ $? -gt 2 ]; then
  echo "Arguments are only numbers."
fi
sed -e "s/n_user [0-9]\+/n_user ${TESTDATA_USER_NUM}/" \
    -e "s/n_entry [0-9]\+/n_entry ${TESTDATA_ENTRY_NUM}/" \
 $SCRIPT_PATH/ex3.init.sql > $SCRIPT_PATH/ex3.init.sql.dist
mv $SCRIPT_PATH/ex3.init.sql.dist $SCRIPT_PATH/ex3.init.sql

sed -e "s/n_user [0-9]\+/n_user ${TESTDATA_USER_NUM}/" \
    -e "s/n_entry [0-9]\+/n_entry ${TESTDATA_ENTRY_NUM}/" \
 $SCRIPT_PATH/ex3a.sql > $SCRIPT_PATH/ex3a.sql.dist
mv $SCRIPT_PATH/ex3a.sql.dist $SCRIPT_PATH/ex3a.sql

sed -e "s/n_user [0-9]\+/n_user ${TESTDATA_USER_NUM}/" \
    -e "s/n_entry [0-9]\+/n_entry ${TESTDATA_ENTRY_NUM}/" \
 $SCRIPT_PATH/ex3b.sql > $SCRIPT_PATH/ex3b.sql.dist
mv $SCRIPT_PATH/ex3b.sql.dist $SCRIPT_PATH/ex3b.sql

sed -e "s/n_user [0-9]\+/n_user ${TESTDATA_USER_NUM}/" \
    -e "s/n_entry [0-9]\+/n_entry ${TESTDATA_ENTRY_NUM}/" \
 $SCRIPT_PATH/ex3c.sql > $SCRIPT_PATH/ex3c.sql.dist
mv $SCRIPT_PATH/ex3c.sql.dist $SCRIPT_PATH/ex3c.sql

for FILE_NAME in $(find {.,/var/lib/pgsql} -name postmaster.pid)
do
  pg_ctl stop -w -D $(dirname $FILE_NAME) -m f
done
rm -rf $EXDATA_PATH/ex3

initdb -D $EXDATA_PATH/ex3 -E UTF8 --no-locale
cp $EXDATA_PATH/ex3/postgresql.conf $EXDATA_PATH/ex3/postgresql.conf.ORG
cat <<'EOF' >> $EXDATA_PATH/ex3/postgresql.conf

# ex3
max_connections = 500
wal_buffers = 16MB
fsync = off
full_page_writes = off
checkpoint_completion_target = 0.9
max_wal_size = 3GB
EOF
sed -e "s/shared_buffers = 128MB/shared_buffers = 512MB/" \
 $EXDATA_PATH/ex3/postgresql.conf > postgresql.conf.dist
mv postgresql.conf.dist $EXDATA_PATH/ex3/postgresql.conf

pg_ctl start -w -D $EXDATA_PATH/ex3 -o "-p 5434"
createdb -p 5434 ex3
psql -p 5434 -f $SCRIPT_PATH/ex3.init.sql ex3
pg_ctl stop -D $EXDATA_PATH/ex3
mv $EXDATA_PATH/ex3/postgresql.conf.ORG $EXDATA_PATH/ex3/postgresql.conf

sed -e "s/#logging_collector = off/logging_collector = on/" \
    -e "s/#log_line_prefix = ''/log_line_prefix = '%t [%p] '/" \
    -e "s/#listen_addresses = 'localhost'/listen_addresses = '*'/" \
 $EXDATA_PATH/ex3/postgresql.conf > postgresql.conf.dist
mv postgresql.conf.dist $EXDATA_PATH/ex3/postgresql.conf

cp $SCRIPT_PATH/ex3?.sql $EXDATA_PATH/
cp $SCRIPT_PATH/ex3_pgbench.sh $EXDATA_PATH/
